@@ -4,6 +4,7 @@ import time
 from base64 import b64encode, b64decode
 from urllib import urlencode
 from cgi import parse_qs
+import logging
 
 from django.conf import settings
 
@@ -18,20 +19,9 @@ def wrap_url(url, **kwargs):
     """
     Create new authorization key and append it to the url.
     """
-
-    if not 'uid' in kwargs:
-        raise Exception('wrap_url function requires uid name argument')
-
-    key_id = AuthKey.objects.create_key(**kwargs)
-    clue = '?' in url and '&' or '?'
-    parts = url.rsplit('#', 1)
-    if len(parts) > 1:
-        url, hash = parts
-        hash = '#%s' % hash
-    else:
-        hash = ''
-    url = '%s%s%s=%s%s' % (url, clue, settings.URLAUTH_AUTHKEY_NAME, key_id, hash)
-    return url
+    
+    logging.error('urlauth.util.wrap_url is deprecated. Use AuthKey.objects.wrap_url instead.')
+    return AuthKey.objects.wrap_url(url, **kwargs)
 
 
 def load_key(hash):
